@@ -1,8 +1,8 @@
 var interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel =
 [
-    [ "XContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#af6ae5305e870fed4fed86172d6d7fe60", null ],
-    [ "XComponent", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#affe8ef6c7d1653b20260774276d31511", null ],
-    [ "XCloneable", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#a140619de163e25c388bb30b1e58e73f1", null ],
+    [ "::com::sun::star::container::XContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#af6ae5305e870fed4fed86172d6d7fe60", null ],
+    [ "::com::sun::star::lang::XComponent", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#affe8ef6c7d1653b20260774276d31511", null ],
+    [ "::com::sun::star::util::XCloneable", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#a140619de163e25c388bb30b1e58e73f1", null ],
     [ "addColumn", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#ab064f180662d0e5f31536f21e9247037", null ],
     [ "createColumn", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#acbf674154787c10db404fa2544525302", null ],
     [ "getColumn", "interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#a1518b8fdadcf86b4bc1387f9429fe298", null ],
