@@ -1,20 +1,5 @@
 var NAVTREEINDEX108 =
 {
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a0149ac9c0344cfbfd5771ce1a96af612":[2,0,0,0,0,1,10,83],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a047e134a70c9674c249189da852b7a2f":[2,0,0,0,0,1,10,1],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a0f24fca792ea9447f554d42ab470de4f":[2,0,0,0,0,1,10,80],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a105d61332f9450fb1986a38e7243c3aa":[2,0,0,0,0,1,10,71],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a1aa80df02612c41e536a816a400f3bb5":[2,0,0,0,0,1,10,34],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a1c7699fda56a77e61bc5c68821516a89":[2,0,0,0,0,1,10,41],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a1d8b45aa9007a62a0e226fa2bf028ab5":[2,0,0,0,0,1,10,30],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a1e0d42bd19f395c55d54600a36e5e7e2":[2,0,0,0,0,1,10,48],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a1f7cd1ecebb7481b48efb0a4cd8ad55c":[2,0,0,0,0,1,10,24],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a215361a059cc7a28f19e2b9948eb889b":[2,0,0,0,0,1,10,22],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a2153f8d948217edcb9fd34e46a13be00":[2,0,0,0,0,1,10,40],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a216e65f2338c2df0f1672e0dafc642c4":[2,0,0,0,0,1,10,32],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a21a0ca8b29ba26df4b7b2363b8b845ed":[2,0,0,0,0,1,10,109],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a221adbca538a422ea9861a5c2b2ba001":[2,0,0,0,0,1,10,113],
-"namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a23c6c18f730b9065bf7bda7ead0ebbce":[2,0,0,0,0,1,10,72],
 "namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a2454e6f25291699f7c6d54bdca6e84bd":[2,0,0,0,0,1,10,16],
 "namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a29428e4823cf7b7d1bbdc0fd8d9ebdf2":[2,0,0,0,0,1,10,9],
 "namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#a2a209f8c3aa0a891133accafe4aa6b1c":[2,0,0,0,0,1,10,4],
@@ -249,5 +234,20 @@ var NAVTREEINDEX108 =
 "namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#a4c3a2876cbc177746fb3e7a0052ea986":[2,0,0,0,0,3,3,2],
 "namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#a6e8d6d35f69d34df4eb3f8c93696f42a":[2,0,0,0,0,3,3,0],
 "namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#a87372b251f376905db64ce9140eaa590":[2,0,0,0,0,3,3,7],
-"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#a986e98c93dd4277fe248e6d7509eaf47":[2,0,0,0,0,3,3,6]
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#a986e98c93dd4277fe248e6d7509eaf47":[2,0,0,0,0,3,3,6],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#aab5d015605a35732ad668f55fadaa41f":[2,0,0,0,0,3,3,9],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#abaac07594edff951d9f09e51fbdf5b31":[2,0,0,0,0,3,3,3],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#ac85aec30a89e81b9ddca4dffa5ddaada":[2,0,0,0,0,3,3,13],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#ac9379ee7b369fc7704cacedc0a86f0c0":[2,0,0,0,0,3,3,4],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FieldUnit.html#ad1479a5106fc3e01e15bdeafcc5e2b14":[2,0,0,0,0,3,3,8],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html":[2,0,0,0,0,3,4],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#a7ec3130c0fc0cb058c0586860be6f630":[2,0,0,0,0,3,4,1],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#aaa2ca7fbd7a2de1276a2d1af241648a6":[2,0,0,0,0,3,4,3],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#ab8bff9ed4c2282bfb62dc8ddd7dbb8d4":[2,0,0,0,0,3,4,2],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#ac26d908982917554689e3f91f42cc349":[2,0,0,0,0,3,4,0],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#ad71753d25f55889ce276c44daaa430c1":[2,0,0,0,0,3,4,6],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#adc5bfacad878b61e9ced566eb9e1fcf1":[2,0,0,0,0,3,4,5],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html#aeb7bfa10d5d78e48666b79b6dc90c698":[2,0,0,0,0,3,4,4],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FontEmphasisMark.html":[2,0,0,0,0,3,5],
+"namespacecom_1_1sun_1_1star_1_1awt_1_1FontEmphasisMark.html#a25686ce0ceb38abc5028c6385100ecff":[2,0,0,0,0,3,5,5]
 };
