@@ -1,5 +1,24 @@
 var NAVTREEINDEX193 =
 {
+"structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html#a490e81f3cb983e1fbb7f710f8926c0c4":[3,0,0,0,0,7,48,1],
+"structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html#a6fc7d3ba2f4df953340c12686cbd0774":[2,0,0,0,0,7,52,0],
+"structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html#a6fc7d3ba2f4df953340c12686cbd0774":[3,0,0,0,0,7,48,0],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html":[2,0,0,0,0,7,53],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html":[3,0,0,0,0,7,49],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a1281cbb1b46c07f65149b055bde8c302":[2,0,0,0,0,7,53,4],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a1281cbb1b46c07f65149b055bde8c302":[3,0,0,0,0,7,49,4],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a2017cedbb5d287595466be06ea53cb86":[2,0,0,0,0,7,53,6],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a2017cedbb5d287595466be06ea53cb86":[3,0,0,0,0,7,49,6],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a66f1dd85480043942963ac83673e6970":[2,0,0,0,0,7,53,1],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a66f1dd85480043942963ac83673e6970":[3,0,0,0,0,7,49,1],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a79f9492eb784a2ae0323d4d31b179a8a":[2,0,0,0,0,7,53,0],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a79f9492eb784a2ae0323d4d31b179a8a":[3,0,0,0,0,7,49,0],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a7dc7e62bb820b6e06755b02a83dde2c3":[2,0,0,0,0,7,53,3],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a7dc7e62bb820b6e06755b02a83dde2c3":[3,0,0,0,0,7,49,3],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a9e6c4c9113c06087cc24630a1b70c86f":[2,0,0,0,0,7,53,5],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#a9e6c4c9113c06087cc24630a1b70c86f":[3,0,0,0,0,7,49,5],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#ac9125eba7f4b60659a243b0f6d79f54b":[2,0,0,0,0,7,53,2],
+"structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html#ac9125eba7f4b60659a243b0f6d79f54b":[3,0,0,0,0,7,49,2],
 "structcom_1_1sun_1_1star_1_1chart2_1_1data_1_1HighlightedRange.html":[2,0,0,0,0,7,1,6],
 "structcom_1_1sun_1_1star_1_1chart2_1_1data_1_1HighlightedRange.html":[3,0,0,0,0,7,0,6],
 "structcom_1_1sun_1_1star_1_1chart2_1_1data_1_1HighlightedRange.html#a519d47545583de9fa357bc86bd2dd2b6":[2,0,0,0,0,7,1,6,2],
@@ -230,24 +249,5 @@ var NAVTREEINDEX193 =
 "structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html":[3,0,0,0,0,14,44],
 "structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html#a29ecc272afa6add0f1ee6ac762ffe390":[2,0,0,0,0,14,49,0],
 "structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html#a29ecc272afa6add0f1ee6ac762ffe390":[3,0,0,0,0,14,44,0],
-"structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html#abe550c180e5a7d98153c0cba2ef182c1":[2,0,0,0,0,14,49,1],
-"structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html#abe550c180e5a7d98153c0cba2ef182c1":[3,0,0,0,0,14,44,1],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html":[2,0,0,0,0,15,20],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html":[3,0,0,0,0,15,11],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#a0c41ab1135fb338045777af3367d99c3":[2,0,0,0,0,15,20,3],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#a0c41ab1135fb338045777af3367d99c3":[3,0,0,0,0,15,11,3],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#ab1c0caac423675c2817a10261572d4e1":[2,0,0,0,0,15,20,2],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#ab1c0caac423675c2817a10261572d4e1":[3,0,0,0,0,15,11,2],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#ad065b3d6d4be70ceceb0bc914b9f51e2":[2,0,0,0,0,15,20,0],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#ad065b3d6d4be70ceceb0bc914b9f51e2":[3,0,0,0,0,15,11,0],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#afa643e215a42b066037403cc667fa0e1":[2,0,0,0,0,15,20,1],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html#afa643e215a42b066037403cc667fa0e1":[3,0,0,0,0,15,11,1],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html":[2,0,0,0,0,15,21],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html":[3,0,0,0,0,15,12],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#a7b62e9cc64403c71647033bc4068b2f7":[2,0,0,0,0,15,21,1],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#a7b62e9cc64403c71647033bc4068b2f7":[3,0,0,0,0,15,12,1],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#ac1c6a6001bcc2f9f17d50d1b4743da11":[2,0,0,0,0,15,21,0],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#ac1c6a6001bcc2f9f17d50d1b4743da11":[3,0,0,0,0,15,12,0],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#af994b11eefd984bb22d4dd8f56f75d2b":[2,0,0,0,0,15,21,2],
-"structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html#af994b11eefd984bb22d4dd8f56f75d2b":[3,0,0,0,0,15,12,2]
+"structcom_1_1sun_1_1star_1_1document_1_1UndoManagerEvent.html#abe550c180e5a7d98153c0cba2ef182c1":[2,0,0,0,0,14,49,1]
 };
