@@ -1,24 +1,5 @@
 var NAVTREEINDEX61 =
 {
-"interfacecom_1_1sun_1_1star_1_1form_1_1XSubmitListener.html":[3,0,0,0,0,17,56],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XSubmitListener.html#a25bbc923432ba3183fc8581bf3c2d65a":[2,0,0,0,0,17,57,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XSubmitListener.html#a25bbc923432ba3183fc8581bf3c2d65a":[3,0,0,0,0,17,56,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html":[2,0,0,0,0,17,58],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html":[3,0,0,0,0,17,57],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html#a9609bd854cd251d8318ced313ead3e88":[2,0,0,0,0,17,58,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html#a9609bd854cd251d8318ced313ead3e88":[3,0,0,0,0,17,57,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html#a961a4765a9df32976650495f9fc3e85d":[2,0,0,0,0,17,58,1],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html#a961a4765a9df32976650495f9fc3e85d":[3,0,0,0,0,17,57,1],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html":[2,0,0,0,0,17,59],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html":[3,0,0,0,0,17,58],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html#a20ff64c2edf3eeb97554f68c9cfdffca":[2,0,0,0,0,17,59,1],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html#a20ff64c2edf3eeb97554f68c9cfdffca":[3,0,0,0,0,17,58,1],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html#a5ea561cd11564dc64e9233d60fee3c0b":[2,0,0,0,0,17,59,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateListener.html#a5ea561cd11564dc64e9233d60fee3c0b":[3,0,0,0,0,17,58,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html":[2,0,0,0,0,17,0,17],
-"interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html":[3,0,0,0,0,17,0,17],
-"interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html#a5c47f86714af731d2ac2e1cdee243df9":[2,0,0,0,0,17,0,17,0],
-"interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html#a5c47f86714af731d2ac2e1cdee243df9":[3,0,0,0,0,17,0,17,0],
 "interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html#ac714dab0a9a113d4c9c14d2cbc181bcb":[2,0,0,0,0,17,0,17,1],
 "interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XBindableValue.html#ac714dab0a9a113d4c9c14d2cbc181bcb":[3,0,0,0,0,17,0,17,1],
 "interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntryListener.html":[2,0,0,0,0,17,0,18],
@@ -249,5 +230,24 @@ var NAVTREEINDEX61 =
 "interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html":[3,0,0,0,0,19,69],
 "interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#a218348dddaad1a1e1eaeb60a4db66dc6":[2,0,0,0,0,19,76,3],
 "interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#a218348dddaad1a1e1eaeb60a4db66dc6":[3,0,0,0,0,19,69,3],
-"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#a58d1d9983acce4dac85b6f14ac83e5fd":[2,0,0,0,0,19,76,2]
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#a58d1d9983acce4dac85b6f14ac83e5fd":[2,0,0,0,0,19,76,2],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#a58d1d9983acce4dac85b6f14ac83e5fd":[3,0,0,0,0,19,69,2],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#adac116554b543b7c4228c018a85882f5":[2,0,0,0,0,19,76,1],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#adac116554b543b7c4228c018a85882f5":[3,0,0,0,0,19,69,1],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#ae2f3308962522a555163fc01cdf7b80b":[2,0,0,0,0,19,76,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html#ae2f3308962522a555163fc01cdf7b80b":[3,0,0,0,0,19,69,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XControlNotificationListener.html":[2,0,0,0,0,19,80],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XControlNotificationListener.html":[3,0,0,0,0,19,73],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XControlNotificationListener.html#a913d616bad9b6cfec682084d8b0e6430":[2,0,0,0,0,19,80,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XControlNotificationListener.html#a913d616bad9b6cfec682084d8b0e6430":[3,0,0,0,0,19,73,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html":[2,0,0,0,0,19,77],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html":[3,0,0,0,0,19,70],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a208c7a58951a8d43ccb89e40864fa042":[2,0,0,0,0,19,77,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a208c7a58951a8d43ccb89e40864fa042":[3,0,0,0,0,19,70,0],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a545c5165573e3c9dda0238be2b3b74ae":[2,0,0,0,0,19,77,5],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a545c5165573e3c9dda0238be2b3b74ae":[3,0,0,0,0,19,70,5],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a81817fdd95b7ce14cb08e1cb581b9fc1":[2,0,0,0,0,19,77,3],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a81817fdd95b7ce14cb08e1cb581b9fc1":[3,0,0,0,0,19,70,3],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a9a87acba0b4f0f682376f241f20aa9ea":[2,0,0,0,0,19,77,6],
+"interfacecom_1_1sun_1_1star_1_1frame_1_1XController.html#a9a87acba0b4f0f682376f241f20aa9ea":[3,0,0,0,0,19,70,6]
 };
